@@ -2,6 +2,10 @@ from vinca import parsing, functions
 from vinca.lib.classes import Card
 from vinca.lib.ansi import ansi
 import sys
+from pathlib import Path
+
+vinca_path = Path(__file__).parent 
+cards_path = vinca_path / 'cards'
 
 # parse the command line arguments
 parser = parsing.parser
@@ -15,6 +19,10 @@ if not sys.stdin.isatty():
 		args.cards.append(Card(id))
 	# reconnect stdin to tty in case we used a pipe
 	sys.stdin = open('/dev/tty')  
+# operate on all the cards by default
+if not args.cards:
+	args.cards = [Card(int(id.name)) for id in cards_path.iterdir()]
+
 	
 # run the specified function
 print(ansi['line_wrap_off'],end='')
