@@ -14,4 +14,4 @@ def generate(args):
 	for card in new_cards:
 		# card.tags = card.tags + args.tags
 		card.make_string()
-		card.add_history(TODAY, elapsed, 0)
+		card.add_history(TODAY, elapsed, 'create')
