@@ -1,37 +1,31 @@
 # The metareviewer which implements specific reviewers
-import time, datetime
-today = datetime.date.today()
 import importlib
+import time, datetime
+
+TODAY = datetime.date.today()
 	
-grade_dict = {'x': -1,
-	      'd': -1,
-	      'q': 0,
-	      'e': 0,
-	      '\x1b': 0, # <ESC>
-	      '1': 1,
-	      '2': 2,
-	      '3': 3,
-	      '4': 4,
-	      ' ': 3,
-	      '\r': 3,
-	      '\n': 3}
-def review(card, mode='review'):
-	assert mode in ['review','preview']
+GRADE_DICT = {'x': 'delete', 'd': 'delete',
+	      'q': 'exit', '\x1b': 'exit',
+	      '1': 'again',
+	      '2': 'hard',
+	      '3': 'good', ' ': 'good', '\r': 'good', '\n': 'good',
+	      '4': 'easy'}
+
+def review(card):
 
 	start = time.time()
 
 	# dynamically import the required reviewer module
 	# a specifc reviewer is responsible for returning a key to the generic reviewer
 	m = importlib.import_module('.'+card.reviewer, package = 'vinca.reviewers')
-	key = m.review(card, mode)  # the reviewer gives back the key
+	key = m.review(card)  # the reviewer gives back the key
 
 	stop = time.time()
 	elapsed = int(stop - start)
 
-	grade = grade_dict[key] if key in grade_dict else 0
-	grade = grade if mode=='review' or grade<0 else 0
+	grade = GRADE_DICT[key] if key in GRADE_DICT else 'exit'
 
-	card.add_history(today, elapsed_time, grade)
+	card.add_history(TODAY, elapsed_time, grade)
 
 def make_string(card):
 	m = importlib.import_module('.'+card.reviewer, package = 'vinca.reviewers')
